# Canvas

- [Basics](basics.md)
- [Namespaces](namespaces.md)
- [Canvas Grid](grid.md)
- [Legend](legend.md)
- [Inset and Secondary Axis](inset_second.md)
- [Working with the Backend Objects](native_objects.md)
